import { NgModule, ɵɵdefineInjectable, ɵɵinject, Injectable, Optional } from '@angular/core';
import { BehaviorSubject, fromEvent, of } from 'rxjs';
import { distinctUntilChanged, shareReplay, map } from 'rxjs/operators';

class ResponsiveConfig {
}

class Ng2ResponsiveToolModule {
    static forRoot(config) {
        return {
            ngModule: Ng2ResponsiveToolModule,
            providers: [
                { provide: ResponsiveConfig, useValue: config }
            ]
        };
    }
}
Ng2ResponsiveToolModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: []
            },] }
];

class ResponsiveToolService {
    constructor(sizeConfig) {
        this.sizeConfig = sizeConfig;
        this.size = new BehaviorSubject(null);
        this.isMobile = new BehaviorSubject(null);
        this.sizes = {
            extraSmall: 380,
            small: 600,
            medium: 900,
            large: 1200,
            extraLarge: 1800
        };
        this.size$ = this.size.asObservable().pipe(distinctUntilChanged(), shareReplay(1));
        this.isExtraSmall$ = this.size.asObservable().pipe(map(s => s > this.sizes.extraSmall), distinctUntilChanged());
        this.isSmall$ = this.size.asObservable().pipe(map(s => s > this.sizes.small), distinctUntilChanged());
        this.isMedium$ = this.size.asObservable().pipe(map(s => s > this.sizes.medium), distinctUntilChanged());
        this.isLarge$ = this.size.asObservable().pipe(map(s => s > this.sizes.large), distinctUntilChanged());
        this.isExtraLarge$ = this.size.asObservable().pipe(map(s => s > this.sizes.extraLarge), distinctUntilChanged());
        this.isMobile$ = this.isMobile.asObservable().pipe(distinctUntilChanged(), shareReplay(1));
        this.isDesktop$ = this.isMobile$.pipe(map(d => !d));
        this.sizes = sizeConfig !== null && sizeConfig !== void 0 ? sizeConfig : this.sizes;
        this.size.next(window.innerWidth);
        fromEvent(window, 'resize').subscribe(e => {
            this.size.next(window.innerWidth);
            this.isMobile.next(this.detectIsMobile);
        });
        this.isMobile.next(this.detectIsMobile);
    }
    get detectIsMobile() {
        return /iPhone|iPad|iPod|Android|webOS|Windows Phone|BlackBerry/i.test(navigator.userAgent);
    }
    match(condition) {
        return of(window.matchMedia(`(${condition})`).matches).pipe(distinctUntilChanged());
    }
}
ResponsiveToolService.ɵprov = ɵɵdefineInjectable({ factory: function ResponsiveToolService_Factory() { return new ResponsiveToolService(ɵɵinject(ResponsiveConfig, 8)); }, token: ResponsiveToolService, providedIn: "root" });
ResponsiveToolService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
ResponsiveToolService.ctorParameters = () => [
    { type: ResponsiveConfig, decorators: [{ type: Optional }] }
];

/*
 * Public API Surface of ng2-responsive
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Ng2ResponsiveToolModule, ResponsiveConfig, ResponsiveToolService };
//# sourceMappingURL=ng2-responsive-tool.js.map
